==> gnuhealth-3.8.0.tar.gz: gnuhealth-3.8.0/health_imaging/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
#
#    Copyright (C) 2013  Sebastián Marro <smarro@thymbra.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from trytond.pool import Pool
from .health_imaging import *
from .wizard import *


def register():
    Pool.register(
        GnuHealthSequences,
        GnuHealthSequenceSetup,
        ImagingTestType,
        ImagingTest,
        ImagingTestRequest,
        ImagingTestResult,
        RequestImagingTest,
        RequestPatientImagingTestStart,
        module='health_imaging', type_='model')
    Pool.register(
        WizardGenerateResult,
        RequestPatientImagingTest,
        module='health_imaging', type_='wizard')

==> gnuhealth-4.0.5.tar.gz: gnuhealth-4.0.5/health_imaging/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
#
#    Copyright (C) 2013  Sebastián Marro <smarro@thymbra.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from trytond.pool import Pool
from . import health_imaging
from . import wizard
from . import sequences


def register():
    Pool.register(
        health_imaging.ImagingTestType,
        health_imaging.ImagingTest,
        health_imaging.ImagingTestRequest,
        health_imaging.ImagingTestResult,
        wizard.RequestImagingTest,
        wizard.RequestPatientImagingTestStart,
        sequences.GnuHealthSequences,
        sequences.ImagingRequestSequence,
        sequences.ImagingTestSequence,
        module='health_imaging', type_='model')
    Pool.register(
        wizard.WizardGenerateResult,
        wizard.RequestPatientImagingTest,
        module='health_imaging', type_='wizard')
